@@ -1,4 +1,5 @@
-from typing import Any, Dict, List, Optional, TypedDict
+from typing import Any, Dict, List, Optional
+from typing_extensions import TypedDict
 
 from .base import Base
 
@@ -157,3 +158,13 @@ class Users(Base):
         return self._delete(
             "{0}/crypto_wallets/{1}".format(self.user_url, crypto_wallet_id)
         )
+
+    def delete_password(self, password_id: str):
+        return self._delete(
+            "{0}/passwords/{1}".format(self.user_url, password_id)
+        )
+
+    def delete_biometric_registration(self, biometric_registration_id: str):
+        return self._delete(
+            "{0}/biometric_registrations/{1}".format(self.user_url, biometric_registration_id)
+        )
